@@ -1,33 +1,33 @@
 ##' Use wordcloud algorithm to get group tags
 ##'
 ##' @param cluster a cluster name
-##' @param node_data the data section of the ggplot object,
+##' @param ggData the data section of the ggraph object,
 ##' which contains clustering information.
 ##' @param nWords the number of words in the cluster tags
-#' @importFrom utils head
+##' @importFrom magrittr %>%
 ##' @noRd
-get_wordcloud <- function(cluster, node_data, nWords = 4) {
-    cluster_terms <- node_data$name[node_data$color2 == cluster]    
+get_wordcloud <- function(cluster, ggData, nWords = 4) {
+    cluster_terms <- ggData$name[ggData$color2 == cluster]
 
     if (length(cluster_terms) == 0) {
         return(cluster)
     }
 
-    words <- cluster_terms |>
-        tolower() |>
-        gsub(" in ", " ", x = _) |>
-        gsub(" [0-9]+ ", " ", x = _) |>
-        gsub("^[0-9]+ ", "", x = _) |>
-        gsub(" [0-9]+$", "", x = _) |>
-        gsub(" [a-z] ", " ", x = _) |>
-        gsub("^[a-z] ", "", x = _) |>
-        gsub(" [a-z]$", "", x = _) |>
-        gsub(" / ", " ", x = _) |>
-        gsub(" and ", " ", x = _) |>
-        gsub(" of ", " ", x = _) |>
-        gsub(",", " ", x = _) |>
-        gsub(" - ", " ", x = _) |>
-        gsub("\\s+", " ", x = _) |> # multiple spaces to single space
+    words <- cluster_terms %>%
+        tolower() %>%
+        gsub(" in ", " ", .) %>%
+        gsub(" [0-9]+ ", " ", .) %>%
+        gsub("^[0-9]+ ", "", .) %>%
+        gsub(" [0-9]+$", "", .) %>%
+        gsub(" [a-z] ", " ", .) %>%
+        gsub("^[a-z] ", "", .) %>%
+        gsub(" [a-z]$", "", .) %>%
+        gsub(" / ", " ", .) %>%
+        gsub(" and ", " ", .) %>%
+        gsub(" of ", " ", .) %>%
+        gsub(",", " ", .) %>%
+        gsub(" - ", " ", .) %>%
+        gsub("\\s+", " ", .) %>% # multiple spaces to single space
         trimws() # remove leading/trailing whitespace
 
     # Split into words and calculate frequencies
